Skip site navigation (1)Skip section navigation (2)
Date:      Mon, 2 May 2016 12:19:14 -0400 (EDT)
From:      Benjamin Kaduk <kaduk@MIT.EDU>
To:        "Bjoern A. Zeeb" <bz@FreeBSD.org>
Cc:        cem@FreeBSD.org, Benjamin Kaduk <bjkfbsd@gmail.com>, "svn-src-head@freebsd.org" <svn-src-head@FreeBSD.org>, "svn-src-all@freebsd.org" <svn-src-all@FreeBSD.org>, "src-committers@freebsd.org" <src-committers@FreeBSD.org>
Subject:   Re: svn commit: r298924 - head/usr.bin/sdiff
Message-ID:  <alpine.GSO.1.10.1605021216230.26829@multics.mit.edu>
In-Reply-To: <7DC09622-48D4-41C4-8913-9039D44BC1E7@FreeBSD.org>
References:  <201605021507.u42F7hI3029685@repo.freebsd.org> <CAG6CVpUUNW-LN7F117yfH1-zZVVSoaxMULiLS6ApfD%2BinPSEFg@mail.gmail.com> <9AEBC481-D541-451F-82E0-7BCD571B0F93@FreeBSD.org> <CAJ5_RoAosXjNe9gmAquY9MPCUy-R4uCQD3XkSuDTBSGcoJ6Fcg@mail.gmail.com> <CAG6CVpX2DTAGyRXyndki0y5ZGzjpEudBhn9i8xN7N98qMCwGSQ@mail.gmail.com> <7DC09622-48D4-41C4-8913-9039D44BC1E7@FreeBSD.org>

next in thread | previous in thread | raw e-mail | index | archive | help
On Mon, 2 May 2016, Bjoern A. Zeeb wrote:

>
> > On 02 May 2016, at 16:08 , Conrad Meyer <cem@FreeBSD.org> wrote:
> >
> > On Mon, May 2, 2016 at 8:57 AM, Benjamin Kaduk <bjkfbsd@gmail.com> wrot=
e:
> >> On Mon, May 2, 2016 at 10:54 AM, Bjoern A. Zeeb <bz@freebsd.org> wrote=
:
> >>>> On 02 May 2016, at 15:32 , Conrad Meyer <cem@FreeBSD.org> wrote:
> >>>>
> >>>> Clang should really catch this too.  Why didn=E2=80=99t it?
> >>>
> >>> It was only powerpc;  sparc64 and mips were good as well.
> >>
> >> 'char' being signed vs. unsigned?
> >
> > Yeah, that occurred to me, but EOF should be out of range for any char
> > type.  I'd like ((char)getchar() =3D=3D EOF) to warn on all platforms.
>
> I think we just define EOF to be -1.  Someone should check, and that the =
warning message might be misleading.

Yeah, stdio.h has:

#define EOF     (-1)

If char is signed, that gets more exciting, due to the value-preserving
promotion rule (after the char cast, it gets converted back to int for the
comparison operation).

Also, -1 is assumed to be EOF in external code, e.g.,
contrib/top/getopt.c.

-Ben
From owner-svn-src-all@freebsd.org  Mon May  2 16:47:30 2016
Return-Path: <owner-svn-src-all@freebsd.org>
Delivered-To: svn-src-all@mailman.ysv.freebsd.org
Received: from mx1.freebsd.org (mx1.freebsd.org
 [IPv6:2001:1900:2254:206a::19:1])
 by mailman.ysv.freebsd.org (Postfix) with ESMTP id D6AF4B296E7;
 Mon,  2 May 2016 16:47:30 +0000 (UTC) (envelope-from pfg@FreeBSD.org)
Received: from repo.freebsd.org (repo.freebsd.org
 [IPv6:2610:1c1:1:6068::e6a:0])
 (using TLSv1.2 with cipher ECDHE-RSA-AES256-GCM-SHA384 (256/256 bits))
 (Client did not present a certificate)
 by mx1.freebsd.org (Postfix) with ESMTPS id 9F7D1138C;
 Mon,  2 May 2016 16:47:30 +0000 (UTC) (envelope-from pfg@FreeBSD.org)
Received: from repo.freebsd.org ([127.0.1.37])
 by repo.freebsd.org (8.15.2/8.15.2) with ESMTP id u42GlTAn061662;
 Mon, 2 May 2016 16:47:29 GMT (envelope-from pfg@FreeBSD.org)
Received: (from pfg@localhost)
 by repo.freebsd.org (8.15.2/8.15.2/Submit) id u42GlSGY061648;
 Mon, 2 May 2016 16:47:28 GMT (envelope-from pfg@FreeBSD.org)
Message-Id: <201605021647.u42GlSGY061648@repo.freebsd.org>
X-Authentication-Warning: repo.freebsd.org: pfg set sender to pfg@FreeBSD.org
 using -f
From: "Pedro F. Giffuni" <pfg@FreeBSD.org>
Date: Mon, 2 May 2016 16:47:28 +0000 (UTC)
To: src-committers@freebsd.org, svn-src-all@freebsd.org,
 svn-src-head@freebsd.org
Subject: svn commit: r298931 - in head/sys/dev: ciss drm2/i915 drm2/radeon
 drm2/ttm hptiop hwpmc isci/scil pccbb wbwd wtap wtap/plugins
X-SVN-Group: head
MIME-Version: 1.0
Content-Type: text/plain; charset=UTF-8
Content-Transfer-Encoding: 8bit
X-BeenThere: svn-src-all@freebsd.org
X-Mailman-Version: 2.1.22
Precedence: list
List-Id: "SVN commit messages for the entire src tree \(except for &quot;
 user&quot; and &quot; projects&quot; \)" <svn-src-all.freebsd.org>
List-Unsubscribe: <https://lists.freebsd.org/mailman/options/svn-src-all>,
 <mailto:svn-src-all-request@freebsd.org?subject=unsubscribe>
List-Archive: <http://lists.freebsd.org/pipermail/svn-src-all/>;
List-Post: <mailto:svn-src-all@freebsd.org>
List-Help: <mailto:svn-src-all-request@freebsd.org?subject=help>
List-Subscribe: <https://lists.freebsd.org/mailman/listinfo/svn-src-all>,
 <mailto:svn-src-all-request@freebsd.org?subject=subscribe>
X-List-Received-Date: Mon, 02 May 2016 16:47:30 -0000

Author: pfg
Date: Mon May  2 16:47:28 2016
New Revision: 298931
URL: https://svnweb.freebsd.org/changeset/base/298931

Log:
  etc: minor spelling fixes.
  
  Mostly comments but also some user-visible strings.
  
  MFC after:	2 weeks

Modified:
  head/sys/dev/ciss/ciss.c
  head/sys/dev/drm2/i915/i915_gem.c
  head/sys/dev/drm2/i915/intel_dp.c
  head/sys/dev/drm2/radeon/radeon_fb.c
  head/sys/dev/drm2/ttm/ttm_bo_vm.c
  head/sys/dev/hptiop/hptiop.c
  head/sys/dev/hwpmc/hwpmc_mod.c
  head/sys/dev/isci/scil/scic_phy.h
  head/sys/dev/isci/scil/scic_sds_phy.c
  head/sys/dev/pccbb/pccbb_pci.c
  head/sys/dev/wbwd/wbwd.c
  head/sys/dev/wtap/if_wtap.c
  head/sys/dev/wtap/if_wtap_module.c
  head/sys/dev/wtap/plugins/visibility.c

Modified: head/sys/dev/ciss/ciss.c
==============================================================================
--- head/sys/dev/ciss/ciss.c	Mon May  2 16:16:08 2016	(r298930)
+++ head/sys/dev/ciss/ciss.c	Mon May  2 16:47:28 2016	(r298931)
@@ -464,7 +464,7 @@ ciss_attach(device_t dev)
     ciss_initq_notify(sc);
 
     /*
-     * Initalize device sysctls.
+     * Initialize device sysctls.
      */
     ciss_init_sysctl(sc);
 
@@ -619,7 +619,7 @@ ciss_init_pci(struct ciss_softc *sc)
 	/*
 	 * XXX Big hammer, masks/unmasks all possible interrupts.  This should
 	 * work on all hardware variants.  Need to add code to handle the
-	 * "controller crashed" interupt bit that this unmasks.
+	 * "controller crashed" interrupt bit that this unmasks.
 	 */
 	sqmask = ~0;
     }
@@ -4487,7 +4487,7 @@ ciss_name_ldrive_org(int org)
     case CISS_LDRIVE_RAIDADG:
 	return("RAID ADG");
     }
-    return("unkown");
+    return("unknown");
 }
 
 /************************************************************************

Modified: head/sys/dev/drm2/i915/i915_gem.c
==============================================================================
--- head/sys/dev/drm2/i915/i915_gem.c	Mon May  2 16:16:08 2016	(r298930)
+++ head/sys/dev/drm2/i915/i915_gem.c	Mon May  2 16:47:28 2016	(r298931)
@@ -1600,7 +1600,7 @@ have_page:
 	}
 	DRM_UNLOCK(dev);
 	if (*mres != NULL) {
-		KASSERT(*mres != page, ("loosing %p %p", *mres, page));
+		KASSERT(*mres != page, ("losing %p %p", *mres, page));
 		vm_page_lock(*mres);
 		vm_page_free(*mres);
 		vm_page_unlock(*mres);
@@ -3149,7 +3149,7 @@ static bool i915_gem_valid_gtt_space(str
 
 	/* On non-LLC machines we have to be careful when putting differing
 	 * types of snoopable memory together to avoid the prefetcher
-	 * crossing memory domains and dieing.
+	 * crossing memory domains and dying.
 	 */
 	if (HAS_LLC(dev))
 		return true;

Modified: head/sys/dev/drm2/i915/intel_dp.c
==============================================================================
--- head/sys/dev/drm2/i915/intel_dp.c	Mon May  2 16:16:08 2016	(r298930)
+++ head/sys/dev/drm2/i915/intel_dp.c	Mon May  2 16:47:28 2016	(r298931)
@@ -1959,7 +1959,7 @@ intel_dp_complete_link_train(struct inte
 	}
 
 	if (channel_eq)
-		DRM_DEBUG_KMS("Channel EQ done. DP Training successfull\n");
+		DRM_DEBUG_KMS("Channel EQ done. DP Training successful\n");
 
 	intel_dp_set_link_train(intel_dp, DP, DP_TRAINING_PATTERN_DISABLE);
 }

Modified: head/sys/dev/drm2/radeon/radeon_fb.c
==============================================================================
--- head/sys/dev/drm2/radeon/radeon_fb.c	Mon May  2 16:16:08 2016	(r298930)
+++ head/sys/dev/drm2/radeon/radeon_fb.c	Mon May  2 16:47:28 2016	(r298931)
@@ -228,7 +228,7 @@ static int radeonfb_create(struct radeon
 
 	ret = radeon_framebuffer_init(rdev->ddev, &rfbdev->rfb, &mode_cmd, gobj);
 	if (ret) {
-		DRM_ERROR("failed to initalise framebuffer %d\n", ret);
+		DRM_ERROR("failed to initialise framebuffer %d\n", ret);
 		goto out_unref;
 	}
 

Modified: head/sys/dev/drm2/ttm/ttm_bo_vm.c
==============================================================================
--- head/sys/dev/drm2/ttm/ttm_bo_vm.c	Mon May  2 16:16:08 2016	(r298930)
+++ head/sys/dev/drm2/ttm/ttm_bo_vm.c	Mon May  2 16:47:28 2016	(r298931)
@@ -260,7 +260,7 @@ reserve:
 	m->valid = VM_PAGE_BITS_ALL;
 	vm_page_xbusy(m);
 	if (*mres != NULL) {
-		KASSERT(*mres != m, ("loosing %p %p", *mres, m));
+		KASSERT(*mres != m, ("losing %p %p", *mres, m));
 		vm_page_lock(*mres);
 		vm_page_free(*mres);
 		vm_page_unlock(*mres);
@@ -296,7 +296,7 @@ ttm_bo_vm_ctor(void *handle, vm_ooffset_
 	 * acquired either in ttm_bo_mmap() or ttm_bo_vm_open(). It's
 	 * then released in ttm_bo_vm_close().
 	 *
-	 * Here, this function is called during mmap() intialization.
+	 * Here, this function is called during mmap() initialization.
 	 * Thus, the reference acquired in ttm_bo_mmap_single() is
 	 * sufficient.
 	 */

Modified: head/sys/dev/hptiop/hptiop.c
==============================================================================
--- head/sys/dev/hptiop/hptiop.c	Mon May  2 16:16:08 2016	(r298930)
+++ head/sys/dev/hptiop/hptiop.c	Mon May  2 16:47:28 2016	(r298931)
@@ -2408,7 +2408,7 @@ static void hptiop_post_req_itl(struct h
 		iop_req32 = BUS_SPACE_RD4_ITL(inbound_queue);
 
 		if (iop_req32 == IOPMU_QUEUE_EMPTY) {
-			device_printf(hba->pcidev, "invaild req offset\n");
+			device_printf(hba->pcidev, "invalid req offset\n");
 			ccb->ccb_h.status = CAM_BUSY;
 			bus_dmamap_unload(hba->io_dmat, srb->dma_map);
 			hptiop_free_srb(hba, srb);

Modified: head/sys/dev/hwpmc/hwpmc_mod.c
==============================================================================
--- head/sys/dev/hwpmc/hwpmc_mod.c	Mon May  2 16:16:08 2016	(r298930)
+++ head/sys/dev/hwpmc/hwpmc_mod.c	Mon May  2 16:47:28 2016	(r298931)
@@ -1123,7 +1123,7 @@ pmc_detach_one_process(struct proc *p, s
 		pmclog_process_pmcdetach(pm, p->p_pid);
 
 	/*
-	 * If there are no PMCs targetting this process, we remove its
+	 * If there are no PMCs targeting this process, we remove its
 	 * descriptor from the target hash table and unset the P_HWPMC
 	 * flag in the struct proc.
 	 */
@@ -1232,7 +1232,7 @@ pmc_process_csw_in(struct thread *td)
 	    p->p_pid, p->p_comm, pp);
 
 	KASSERT(cpu >= 0 && cpu < pmc_cpu_max(),
-	    ("[pmc,%d] wierd CPU id %d", __LINE__, cpu));
+	    ("[pmc,%d] weird CPU id %d", __LINE__, cpu));
 
 	pc = pmc_pcpu[cpu];
 
@@ -1377,7 +1377,7 @@ pmc_process_csw_out(struct thread *td)
 	    p->p_pid, p->p_comm, pp);
 
 	KASSERT(cpu >= 0 && cpu < pmc_cpu_max(),
-	    ("[pmc,%d wierd CPU id %d", __LINE__, cpu));
+	    ("[pmc,%d weird CPU id %d", __LINE__, cpu));
 
 	pc = pmc_pcpu[cpu];
 
@@ -1907,7 +1907,7 @@ pmc_hook_handler(struct thread *td, int 
 
 		/*
 		 * Log the exec event to all monitoring owners.  Skip
-		 * owners who have already recieved the event because
+		 * owners who have already received the event because
 		 * they had system sampling PMCs active.
 		 */
 		for (ri = 0; ri < md->pmd_npmc; ri++)
@@ -1933,7 +1933,7 @@ pmc_hook_handler(struct thread *td, int 
 		/*
 		 * If the newly exec()'ed process has a different credential
 		 * than before, allow it to be the target of a PMC only if
-		 * the PMC's owner has sufficient priviledge.
+		 * the PMC's owner has sufficient privilege.
 		 */
 
 		for (ri = 0; ri < md->pmd_npmc; ri++)
@@ -4441,7 +4441,7 @@ pmc_process_exit(void *arg __unused, str
 	 * process, we would have context switched IN at some prior
 	 * point.  However, with PREEMPTION, kernel mode context
 	 * switches may happen any time, so we want to disable a
-	 * context switch OUT till we get any PMCs targetting this
+	 * context switch OUT till we get any PMCs targeting this
 	 * process off the hardware.
 	 *
 	 * We also need to atomically remove this process'
@@ -4544,7 +4544,7 @@ pmc_process_exit(void *arg __unused, str
 
 		/*
 		 * Unlink this process from the PMCs that are
-		 * targetting it.  This will send a signal to
+		 * targeting it.  This will send a signal to
 		 * all PMC owner's whose PMCs are orphaned.
 		 *
 		 * Log PMC value at exit time if requested.

Modified: head/sys/dev/isci/scil/scic_phy.h
==============================================================================
--- head/sys/dev/isci/scil/scic_phy.h	Mon May  2 16:16:08 2016	(r298930)
+++ head/sys/dev/isci/scil/scic_phy.h	Mon May  2 16:47:28 2016	(r298931)
@@ -308,7 +308,7 @@ SCI_STATUS scic_sas_phy_get_properties(
 
 /**
  * @brief This method will enable the user to retrieve information
- *        specific to a SATA phy, such as: the recieved signature
+ *        specific to a SATA phy, such as: the received signature
  *        FIS, if a port selector is present, etc.
  *
  * @param[in]  phy this parameter specifies the phy for which to

Modified: head/sys/dev/isci/scil/scic_sds_phy.c
==============================================================================
--- head/sys/dev/pccbb/pccbb_pci.c	Mon May  2 16:16:08 2016	(r298930)
+++ head/sys/dev/pccbb/pccbb_pci.c	Mon May  2 16:47:28 2016	(r298931)
@@ -340,7 +340,7 @@ cbb_pci_attach(device_t brdev)
 	SYSCTL_ADD_UINT(sctx, SYSCTL_CHILDREN(soid), OID_AUTO, "memory",
 	    CTLFLAG_RD, &sc->subbus, 0, "Memory window open");
 	SYSCTL_ADD_UINT(sctx, SYSCTL_CHILDREN(soid), OID_AUTO, "premem",
-	    CTLFLAG_RD, &sc->subbus, 0, "Prefetch memroy window open");
+	    CTLFLAG_RD, &sc->subbus, 0, "Prefetch memory window open");
 	SYSCTL_ADD_UINT(sctx, SYSCTL_CHILDREN(soid), OID_AUTO, "io1",
 	    CTLFLAG_RD, &sc->subbus, 0, "io range 1 open");
 	SYSCTL_ADD_UINT(sctx, SYSCTL_CHILDREN(soid), OID_AUTO, "io2",
@@ -448,7 +448,7 @@ cbb_chipinit(struct cbb_softc *sc)
 	if (pci_read_config(sc->dev, PCIR_LATTIMER, 1) < 0x20)
 		pci_write_config(sc->dev, PCIR_LATTIMER, 0x20, 1);
 
-	/* Enable DMA, memory access for this card and I/O acces for children */
+	/* Enable DMA, memory access for this card and I/O access for children */
 	pci_enable_busmaster(sc->dev);
 	pci_enable_io(sc->dev, SYS_RES_IOPORT);
 	pci_enable_io(sc->dev, SYS_RES_MEMORY);

Modified: head/sys/dev/wbwd/wbwd.c
==============================================================================
--- head/sys/dev/wbwd/wbwd.c	Mon May  2 16:16:08 2016	(r298930)
+++ head/sys/dev/wbwd/wbwd.c	Mon May  2 16:47:28 2016	(r298931)
@@ -754,7 +754,7 @@ wb_attach(device_t dev)
 
 	sc = device_get_softc(dev);
 	KASSERT(sc->ext_cfg_enter_f != NULL && sc->ext_cfg_exit_f != NULL,
-	    ("%s: successfull probe result but not setup correctly", __func__));
+	    ("%s: successful probe result but not setup correctly", __func__));
 
 	/* Watchdog is configured as part of LDN 8 (GPIO Port2, Watchdog). */
 	write_reg(sc, WB_LDN_REG, WB_LDN_REG_LDN8);

Modified: head/sys/dev/wtap/if_wtap.c
==============================================================================
--- head/sys/dev/wtap/if_wtap.c	Mon May  2 16:16:08 2016	(r298930)
+++ head/sys/dev/wtap/if_wtap.c	Mon May  2 16:47:28 2016	(r298931)
@@ -131,7 +131,7 @@ wtap_node_ioctl(struct cdev *dev, u_long
 
 	switch(cmd) {
 	default:
-		DWTAP_PRINTF("Unkown WTAP IOCTL\n");
+		DWTAP_PRINTF("Unknown WTAP IOCTL\n");
 		error = EINVAL;
 	}
 	return error;

Modified: head/sys/dev/wtap/if_wtap_module.c
==============================================================================
--- head/sys/dev/wtap/if_wtap_module.c	Mon May  2 16:16:08 2016	(r298930)
+++ head/sys/dev/wtap/if_wtap_module.c	Mon May  2 16:47:28 2016	(r298931)
@@ -88,7 +88,7 @@
 MALLOC_DEFINE(M_WTAP, "wtap", "wtap wireless simulator");
 MALLOC_DEFINE(M_WTAP_PACKET, "wtap packet", "wtap wireless simulator packet");
 MALLOC_DEFINE(M_WTAP_RXBUF, "wtap rxbuf",
-    "wtap wireless simulator recieve buffer");
+    "wtap wireless simulator receive buffer");
 MALLOC_DEFINE(M_WTAP_PLUGIN, "wtap plugin", "wtap wireless simulator plugin");
 
 static struct wtap_hal		*hal;
@@ -122,7 +122,7 @@ wtap_ioctl(struct cdev *dev, u_long cmd,
 			error = EINVAL;
 		break;
 	default:
-		DWTAP_PRINTF("Unkown WTAP IOCTL\n");
+		DWTAP_PRINTF("Unknown WTAP IOCTL\n");
 		error = EINVAL;
 	}
 

Modified: head/sys/dev/wtap/plugins/visibility.c
==============================================================================
--- head/sys/dev/wtap/plugins/visibility.c	Mon May  2 16:16:08 2016	(r298930)
+++ head/sys/dev/wtap/plugins/visibility.c	Mon May  2 16:47:28 2016	(r298931)
@@ -230,7 +230,7 @@ vis_ioctl(struct cdev *sdev, u_long cmd,
 #endif
 		break;
 	default:
-		DWTAP_PRINTF("Unkown WTAP IOCTL\n");
+		DWTAP_PRINTF("Unknown WTAP IOCTL\n");
 		error = EINVAL;
 	}
 



Want to link to this message? Use this URL: <https://mail-archive.FreeBSD.org/cgi/mid.cgi?alpine.GSO.1.10.1605021216230.26829>
--- head/sys/dev/isci/scil/scic_sds_phy.c	Mon May  2 16:16:08 2016	(r298930)
+++ head/sys/dev/isci/scil/scic_sds_phy.c	Mon May  2 16:47:28 2016	(r298931)
@@ -749,7 +749,7 @@ SCI_STATUS scic_sds_phy_initialize(
       this_phy, link_layer_registers
    ));
 
-   // Perfrom the initialization of the TL hardware
+   // Perform the initialization of the TL hardware
    scic_sds_phy_transport_layer_initialization(this_phy, transport_layer_registers);
 
    // Perofrm the initialization of the PE hardware
@@ -1029,7 +1029,7 @@ SCI_STATUS scic_sds_phy_reset(
 }
 
 /**
  * @brief This method will process the event code recieved.
  *
  * @param[in] this_phy
  * @param[in] event_code
@@ -1052,7 +1052,7 @@ SCI_STATUS scic_sds_phy_event_handler(
 }
 
 /**
  * @brief This method will process the frame index recieved.
  *
  * @param[in] this_phy
  * @param[in] frame_index
@@ -1754,7 +1754,7 @@ SCI_STATUS scic_sds_phy_default_frame_ha
    SCIC_LOG_WARNING((
       sci_base_object_get_logger(this_phy),
       SCIC_LOG_OBJECT_PHY,
-      "SCIC Phy 0x%08x recieved unexpected frame data %d while in state %d\n",
+      "SCIC Phy 0x%08x received unexpected frame data %d while in state %d\n",
       this_phy, frame_index,
       sci_base_state_machine_get_state(&this_phy->parent.state_machine)
    ));
@@ -1866,7 +1866,7 @@ SCI_STATUS scic_sds_phy_stopped_state_st
  * This method takes the SCIC_SDS_PHY from a stopped state and destroys it.
  *    - This function takes no action.
  *
- * @todo Shouldnt this function transition the SCI_BASE_PHY::state_machine to
+ * @todo Shouldn't this function transition the SCI_BASE_PHY::state_machine to
  *        the SCI_BASE_PHY_STATE_FINAL?
  *
  * @param[in] phy This is the SCI_BASE_PHY object which is cast into a
@@ -1964,7 +1964,7 @@ SCI_STATUS scic_sds_phy_ready_state_rese
  *    - decoded event is a link failure
  *       - transition the SCIC_SDS_PHY back to the SCI_BASE_PHY_STATE_STARTING
  *         state.
  *    - any other event recived will report a warning message
  *
  * @param[in] phy This is the SCIC_SDS_PHY object which has received the
  *       event.
@@ -2020,7 +2020,7 @@ SCI_STATUS scic_sds_phy_ready_state_even
       SCIC_LOG_WARNING((
          sci_base_object_get_logger(this_phy),
          SCIC_LOG_OBJECT_PHY | SCIC_LOG_OBJECT_RECEIVED_EVENTS,
-         "SCIC PHY 0x%x ready state machine recieved unexpected event_code %x\n",
+         "SCIC PHY 0x%x ready state machine received unexpected event_code %x\n",
          this_phy, event_code
       ));
       result = SCI_FAILURE_INVALID_STATE;
@@ -2066,7 +2066,7 @@ SCI_STATUS scic_sds_phy_resetting_state_
       SCIC_LOG_WARNING((
          sci_base_object_get_logger(this_phy),
          SCIC_LOG_OBJECT_PHY | SCIC_LOG_OBJECT_RECEIVED_EVENTS,
-         "SCIC PHY 0x%x resetting state machine recieved unexpected event_code %x\n",
+         "SCIC PHY 0x%x resetting state machine received unexpected event_code %x\n",
          this_phy, event_code
       ));
 
@@ -2691,7 +2691,7 @@ SCI_STATUS scic_sds_phy_starting_substat
       SCIC_LOG_WARNING((
          sci_base_object_get_logger(this_phy),
          SCIC_LOG_OBJECT_PHY | SCIC_LOG_OBJECT_RECEIVED_EVENTS,
-         "PHY starting substate machine recieved unexpected event_code %x\n",
+         "PHY starting substate machine received unexpected event_code %x\n",
          event_code
       ));
 
@@ -2772,7 +2772,7 @@ SCI_STATUS scic_sds_phy_starting_substat
       SCIC_LOG_WARNING((
          sci_base_object_get_logger(this_phy),
          SCIC_LOG_OBJECT_PHY | SCIC_LOG_OBJECT_RECEIVED_EVENTS,
-         "PHY starting substate machine recieved unexpected event_code %x\n",
+         "PHY starting substate machine received unexpected event_code %x\n",
          event_code
       ));
 
@@ -2834,7 +2834,7 @@ SCI_STATUS scic_sds_phy_starting_substat
       SCIC_LOG_WARNING((
          sci_base_object_get_logger(this_phy),
          SCIC_LOG_OBJECT_PHY | SCIC_LOG_OBJECT_RECEIVED_EVENTS,
-         "PHY starting substate machine recieved unexpected event_code %x\n",
+         "PHY starting substate machine received unexpected event_code %x\n",
          event_code
       ));
 
@@ -2879,7 +2879,7 @@ SCI_STATUS scic_sds_phy_starting_substat
       SCIC_LOG_WARNING((
          sci_base_object_get_logger(this_phy),
          SCIC_LOG_OBJECT_PHY | SCIC_LOG_OBJECT_RECEIVED_EVENTS,
-         "PHY starting substate machine recieved unexpected event_code %x\n",
+         "PHY starting substate machine received unexpected event_code %x\n",
          event_code
       ));
 
@@ -2935,7 +2935,7 @@ SCI_STATUS scic_sds_phy_starting_substat
       SCIC_LOG_WARNING((
          sci_base_object_get_logger(this_phy),
          SCIC_LOG_OBJECT_PHY | SCIC_LOG_OBJECT_RECEIVED_EVENTS,
-         "PHY starting substate machine recieved unexpected event_code %x\n",
+         "PHY starting substate machine received unexpected event_code %x\n",
          event_code
       ));
 
@@ -3003,7 +3003,7 @@ SCI_STATUS scic_sds_phy_starting_substat
       SCIC_LOG_WARNING((
          sci_base_object_get_logger(this_phy),
          SCIC_LOG_OBJECT_PHY | SCIC_LOG_OBJECT_RECEIVED_EVENTS,
-         "PHY starting substate machine recieved unexpected event_code %x\n",
+         "PHY starting substate machine received unexpected event_code %x\n",
          event_code
       ));
 
@@ -3090,7 +3090,7 @@ SCI_STATUS scic_sds_phy_starting_substat
       SCIC_LOG_WARNING((
          sci_base_object_get_logger(this_phy),
          SCIC_LOG_OBJECT_PHY | SCIC_LOG_OBJECT_RECEIVED_EVENTS,
-         "PHY starting substate machine recieved unexpected event_code %x\n",
+         "PHY starting substate machine received unexpected event_code %x\n",
          event_code
       ));
 
@@ -3147,7 +3147,7 @@ SCI_STATUS scic_sds_phy_starting_substat
       SCIC_LOG_WARNING((
          sci_base_object_get_logger(this_phy),
          SCIC_LOG_OBJECT_PHY | SCIC_LOG_OBJECT_RECEIVED_EVENTS,
-         "PHY starting substate machine recieved unexpected event_code %x\n",
+         "PHY starting substate machine received unexpected event_code %x\n",
          event_code
       ));
 
@@ -3246,7 +3246,7 @@ SCI_STATUS scic_sds_phy_starting_substat
       SCIC_LOG_WARNING((
          sci_base_object_get_logger(this_phy),
          SCIC_LOG_OBJECT_PHY | SCIC_LOG_OBJECT_UNSOLICITED_FRAMES,
-         "PHY starting substate machine recieved unexpected frame id %x\n",
+         "PHY starting substate machine received unexpected frame id %x\n",
          frame_index
       ));
    }
@@ -3332,7 +3332,7 @@ SCI_STATUS scic_sds_phy_starting_substat
       SCIC_LOG_WARNING((
          sci_base_object_get_logger(this_phy),
          SCIC_LOG_OBJECT_PHY | SCIC_LOG_OBJECT_UNSOLICITED_FRAMES,
-         "PHY starting substate machine recieved unexpected frame id %x\n",
+         "PHY starting substate machine received unexpected frame id %x\n",
          frame_index
       ));
    }
@@ -1029,7 +1029,7 @@ SCI_STATUS scic_sds_phy_reset(
 
 /**
- * @brief This method will process the event code recieved.
+ * @brief This method will process the event code received.
  *
  * @param[in] this_phy
@@ -1052,7 +1052,7 @@ SCI_STATUS scic_sds_phy_event_handler(
 
 /**
- * @brief This method will process the frame index recieved.
+ * @brief This method will process the frame index received.
  *
  * @param[in] this_phy
@@ -1964,7 +1964,7 @@ SCI_STATUS scic_sds_phy_ready_state_rese
  *       - transition the SCIC_SDS_PHY back to the SCI_BASE_PHY_STATE_STARTING
  *         state.
- *    - any other event recived will report a warning message
+ *    - any other event received will report a warning message
  *
  * @param[in] phy This is the SCIC_SDS_PHY object which has received the

Modified: head/sys/dev/pccbb/pccbb_pci.c
==============================================================================